import re
import json

# NO FILTER
filters = {
    "not_impl_filter": {},
    "newsfeed.zeit.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "article"}],
            "delete": [
                {"tag": "script"},
                {"tag": "style"},
                {"tag": "figure"},
                {"tag": "input"},
                {"tag": "div", "attrs": [
                    {"attr": "class", "values": ["metadata", "article-heading", "article-footer", "sharing-menu"]}
                ]}
            ]
        }
    },

    "rss.focus.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "meta", "attr": "name", "value": "description"}],
            #"delete": [
              #  {"tag": "script"},
              #  {"tag": "style"},
              #  {"tag": "figure"},
              #  {"tag": "input"},
              #  {"tag": "div", "attrs": [
              #      {"attr": "class", "values": ["articleHead", "mediaBlock", "displayDate", "orange-button-artobj", "teaserList2x2",
              #        "container_multichart", "sidebar"]},
              #      {"attr": "id", "values": ['article-social-holder', 'commentForm', 'comments', 'commentSent']}
              #  ]}
            #],
            #"tag_filters": [{"tag": "p"},
            #                {"tag": "strong"},
            #                {"tag": "span", "attr": "class", "value": "headline"}
            #]
        }
    },

    "www.bild.de": {
    "standard_filter": {
            "entrypoints": [{"tag": "div", "attr": "id", "value": "innerWrapper"}],
            "delete": [#{"tag": "meta"},
                       {"tag": "footer"},
                       {"tag": "script"},
                       {"tag": "nav", "attr": "class", "value": "main-nav"},
                       {"tag": "a", "attr": "class", "value": "external-link"},
                       {"tag": "div", "attrs": [
                            {"attr": "class", "values": ["ob-widget-section", "ob-widget", "s6", "social-sharing flank",
                                                         "socialbar", "element"]}
                        ]}
                    ],
            "tag_filters": [{"tag":"p"},
                            {"tag":"strong"},
                            {"tag": "span", "attr":"class", "value": "headline"}
            ]
        }
    },

    "www.welt.de": {
    "standard_filter": {
            "entrypoints": [{"tag": "div", "attr":"class", "value":"c-page-container"}],
            "delete": [{"tag": "script"}],
            "tag_filters": [{"tag": "span", "attr": "class", "value": "o-headline c-headline c-dreifaltigkeit__headline"},
                            {"tag": "p"},
                            {"tag": "h3"}
            ]
        }
    },

    "www.n-tv.de": {
    "standard_filter": {
            "entrypoints": [{"tag": "article", "attr":"class", "value":"article box section"}],
            "delete": [{"tag": "script"}],
            "tag_filters": [{"tag": "span", "attr": "class", "value": "headline"},
                            {"tag": "p"},
                            {"tag": "strong"}
            ]
        }
    },

    "www.stern.de": {
    "standard_filter": {
        "entrypoints": [{"tag": "article"}],
        "delete": [{"tag": "div", "attr": "class", "value": "sidebar active native"},
                   {"tag": "div", "attr": "class", "value": "tanzspalte"},
                   {"tag": "div", "attr": "class", "value": "ob-widget-section ob-firs"},
                   {"tag": "div", "attr": "class", "value": "s15"},
                   {"tag": "script"}],
        "tag_filters": [{"tag": "p"},
                        {"tag": "h2"}
             ]
        }
    },

#FAZ und RP online werden falsch gefiltert. Es kommt immer der Error UnicodeDecodeError: 
#'unicodeescape' codec can't decode byte 0x5c. Hat bei faz ggf mit Json zu tun(?)
    "www.faz.net": {
    "standard_filter": {
        "entrypoints": [{"tag": "div", "attr": "class","value": "Artikel "}],
        "delete": [{"tag": "script"}],
        "tag_filters": [{"tag": "span", "attr": "class", "value": "atc-HeadlineText"},
                        {"tag": "p"}
            ]
        }
    },

    "www.rp-online.de": {
    "standard_filter": {
        "entrypoints": [{"tag": "article", "attr": "id", "value": "article"}],
        "delete": [{"tag": "script"}],
        "tag_filters": [{"tag": "strong"},
                        {"tag": "p"},
                        {"tag": "h2"},
                        {"tag": "div", "attr": "class", "value": "headline"}
            ]
        }
    },

    "www.hamburg1.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr": "class", "value": "small-12 columns box roundcorners"}],
            "delete":   [{"tag": "script"}],
            "tag_filters": [{"tag": "p"}]
        }
    },

    "www.hamburg-magazin.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr": "class", "value": "article"}],
            "delete":   [{"tag": "script"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "b"},
                            {"tag": "h1"}
            ]
        }
    },

    "www.taz-hamburg.de": {
        "standard_filter": {
                 "delete": [{"tag": "script"}],
            "entrypoints": [{"tag": "div", "attr": "class", "value": "sectbody"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "h1"},
                            {"tag": "strong"}
            ]
        }
    },

    "www.presseportal.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr": "class", "value": "grid-container grid-fourths sticky-track"}],
            "delete": [{"tag": "script"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "h1"}
            ]
        }
    },

    "www.tagesschau.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr":"id", "value":"content"}],
            "delete":   [{"tag": "script"}],
            "tag_filters": [{"tag": "h1"},
                            {"tag": "span", "attr": "class", "value": "headline"},
                            {"tag": "p"},
                            {"tag": "h2"},
                            {"tag": "strong"}
            ]
        }
    },

    "www.radiohamburg.de": {
        "standard_filter": {
            "entrypoints": [{"tag":"div", "attr":"class", "value":"grid_18"}],
            "delete":   [{"tag": "src"},
                         {"tag": "script"}],
            "tag_filters": [{"tag":"p"},
                            {"tag":"h1"},
                            {"tag":"h3"}
            ],
        }
    },

    "www.antenne.com": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr":"class", "value":"container container-fluid"}],
            "delete":   [{"tag": "src"},
                         {"tag": "script"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "h1"}
            ]
        }
    },

    "www.hamburg.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr":"class", "value":"body"}],
            "delete": [{"tag": "src"},
                       {"tag": "script"},
                       {"tag": "div", "attr": "class", "value": "info-box info-box-iason"},
                       {"tag": "div", "attr": "class", "value": "slideshow-container"}
                       ],
            "tag_filters": [{"tag": "p"},
                            {"tag": "strong"},
                            {"tag": "a"},
                            {"tag": "span", "attr":"id", "value":"title"}
            ],
        }
    },

    "www.hinzundkunzt.de": { #keinen gefunden
        "standard_filter": {
               "delete": [{"tag": "src"},
                          {"tag": "script"}],
            "entrypoints": [{"tag": "article"}],
            "tag_filters": [{"tag": "p"}]
        }
    },

#Der Filter gibt uns leider auch sehr viel Mist zurück, aber immerhin kommt der Text durch.
    "www.mopo.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "head"}],
            "delete": [{"tag": "src"},
                       {"tag": "style"},
                       {"tag": "link"},
                       {"tag": "meta"}],
           # "tag_filters": [{"tag": "p"},
           #                 {"tag": "strong"},
           #                 {"tag": "h2"}
            #]
        }
    },

    "www.ndr.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr":"class", "value": "modulepadding copytext"}],
            "delete": []#{"tag": "a"}],
                       #{"tag": "src"},
                       #{"tag": "script"},
                       #{"tag": "div", "attr": "class", "value": "contentbox list voll"},
                       #{"tag": "div", "attr": "class", "value": "ndrgallerystage"}],
        }
    },

    "rtlnord.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "div", "attr": "class", "value": "regional-article-content"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "strong"},
                            {"tag": "h3"}
            ]
        }
    },

    "www.elbe-wochenblatt.de": {
        "standard_filter": {
            "entrypoints": [{"tag": "article"}],
            "delete": [{"tag": "a"},
                       {"tag": "script"},
                       {"tag": "div", "attr": "class", "value": "nocontent"}],
            "tag_filters": [{"tag": "p"},
                            {"tag": "b"},
                            {"tag": "h1"}
            ]
        }
    },

    "www.abendblatt.de": {
        "standard_filter": {
            "entrypoints": [{"tag":"div", "attr":"class", "value": "article-block_voucher_column article-block_voucher_abo-newsletter article-block_voucher_abo-newsletter article-block_voucher_column--signin clearfix"}],
            "delete": [{"tag": "a"}],
            "tag_filters": [{"tag": "p"}]
        }
    }


}

