import re

import pandas as pd
from nltk import word_tokenize
from nltk.corpus import stopwords

import helpers

# Files of classified words from University of Leipzig
neg_words_file = './Sentiment/SentiWS_v1.8c_Negative.txt'
pos_words_file = './Sentiment/SentiWS_v1.8c_Positive.txt'

# create list for each file
negative_words = pd.read_csv(neg_words_file, header=None, names=["1", "2", "3", "4", "5", "6", "7", "8", "9"]).apply(lambda x: x.astype(str).str.lower()).values.tolist()
positive_words = pd.read_csv(pos_words_file, header=None, names=["1", "2", "3", "4", "5", "6", "7", "8", "9"]).apply(lambda x: x.astype(str).str.lower()).values.tolist()

def normalize(x):
    # normalizes a number
    y = ((x+100)/200)*100
    return y

def getFilteredTokens(text):
    """
    getFilteredTokens() deletes stopwords, html tags and links from
    the text and returns a list of tokens
    :param text
    :return: list_of_filtered_tokens
    """
    stop_eng = stopwords.words('english')
    stop_ger = stopwords.words('german')
    customstopwords = ['[', ']', 'Drucken','Nutzungsrechte','Feedback','Kommentieren','Twitter','Facebook','Xing','Linkedin']
    tokens = word_tokenize(text)
    hashtags = [w for w in tokens if w.startswith('#')]
    html = [w for w in tokens if w.startswith('<')]
    links = [w for w in tokens if w.startswith('http') or w.startswith('www')]
    filtered_tokens = [w for w in tokens \
                       if not w in stop_eng \
                       and not w in stop_ger \
                       and not w in customstopwords \
                       and not len(w)<3 \
                       and not w in hashtags \
                       and not w in links \
                       and not w in html]
    words = [w.lower() for w in filtered_tokens]
    regex = r"\W"
    list_of_filtered_tokens = []

    for word in words:
        word = re.sub(regex, '', word)
        list_of_filtered_tokens.append(word)

    return list_of_filtered_tokens

def sentiment_extraction(elem):
    """
    sentiment_extraction() checks if words from the text are positive or negative and sums up the values
    :param: text
    :return: sentiment value between 0 and 100
    """
    text = elem[5]
    sentiment = 0
    tokens = getFilteredTokens(text)
    for t in tokens:
        for elem in negative_words:
            if t in elem:
                sentiment += float(elem[1])
        for elem2 in positive_words:
            if t in elem2:
                sentiment += float(elem2[1])
    if (len(tokens)>0):
        sentiment = normalize((sentiment/len(tokens))*100)
    return sentiment

###################  TEST   ########################
#csv = "./testfiles/website_downloads_cleaned_klein.csv"
#datalist = helpers.createDataframe(csv).values.tolist()
#test_elem = datalist[27]
#
#print(sentiment_extraction(test_elem))
#print(test_elem[5])
####################################################
